@@ -10,10 +10,9 @@
 
 #include <QObject>
 
-class KODayMatrixTest : public QObject
+class KODayMatrixTestUS : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
     void testMatrixLimits();
 };
-
