@@ -209,9 +209,6 @@ Q_SIGNALS:
     /** Emitted when state of modified flag changes */
     void modifiedChanged(bool);
 
-    /** Emitted when state of read-only flag changes */
-    void readOnlyChanged(bool);
-
     /** Emitted when state of events selection has changed and user is organizer*/
     void organizerEventsSelected(bool);
     /** Emitted when state of events selection has changed and user is attendee*/
