@@ -47,12 +47,11 @@ public Q_SLOTS:
 
     void selectWeekByDay(int weekDay, QDate, QDate preferredMonth = QDate());
 
+    void selectADate(QDate d);
     void selectToday();
 
     void selectPreviousYear();
     void selectPreviousMonth(const QDate &currentMonth = QDate(), const QDate &selectionLowerLimit = QDate(), const QDate &selectionUpperLimit = QDate());
-    void selectPreviousWeek();
-    void selectNextWeek();
     void selectNextMonth(const QDate &currentMonth = QDate(), const QDate &selectionLowerLimit = QDate(), const QDate &selectionUpperLimit = QDate());
     void selectNextYear();
 
@@ -77,7 +76,7 @@ private:
       if offset equals -1.
       Bigger offsets are accepted.
     */
-    void shiftMonth(const QDate &date, const QDate &selectionLowerLimit, const QDate &selectionUpperLimit, int offset);
+    void shiftMonth(const QDate &currentMonth, const QDate &selectionLowerLimit, const QDate &selectionUpperLimit, int offset);
 
     KCalendarCore::DateList mSelectedDates;
 
