@@ -39,7 +39,7 @@ public:
     /**
      * Create an Incidence menu instance with a specified style.
      */
-    KOEventPopupMenu(MenuStyle menuStyle, QWidget *parent = nullptr);
+    explicit KOEventPopupMenu(MenuStyle menuStyle, QWidget *parent = nullptr);
 
 public Q_SLOTS:
     /**
@@ -63,7 +63,31 @@ protected Q_SLOTS:
     void toggleTodoCompleted();
     void dissociateOccurrences();
     void forward();
+
+    /**
+     * Start the incidenceeditor to create a new To-do using a few settings from the currently selected incidence
+     * where the current incidence can be a to-do or event.
+     */
+    void createNewTodo();
+
+    /**
+     * Start the incidenceeditor to create a new To-do using a few settings from the currently selected incidence
+     * 1. if current incidence is a to-do, then reuse the start, all-day and due
+     * 2. if current incidence is an event, then reuse almost settings (i.e morph event into to-do)
+     */
     void createTodo();
+
+    /**
+     * Start the incidenceeditor to create a new Event using a few settings from the currently selected incidence
+     * where the current incidence can be a to-do or event.
+     */
+    void createNewEvent();
+
+    /**
+     * Start the incidenceeditor to create a new Event using a few settings from the currently selected incidence
+     * 1. if current incidence is an event, then reuse the start, all-day and end
+     * 2. if current incidence is a to-do, then reuse almost settings (i.e morph to-do into event)
+     */
     void createEvent();
 
 Q_SIGNALS:
@@ -90,13 +114,12 @@ private:
     void appendRecurrenceOnlyItems();
     void appendShareOnlyItems();
 
-    void print(bool previous);
+    void print(bool preview);
 
     Akonadi::CollectionCalendar::Ptr mCurrentCalendar;
     Akonadi::Item mCurrentIncidence;
     QDate mCurrentDate;
 
-    bool mHasAdditionalItems = false;
     QList<QAction *> mEditOnlyItems;
     QList<QAction *> mEventOnlyItems;
     QList<QAction *> mTodoOnlyItems;
