@@ -19,7 +19,7 @@ public:
     void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
-    enum Action {
+    enum class Action : uint8_t {
         Quickview,
         Total
     };
