@@ -12,11 +12,6 @@
 
 class Ui_quickview;
 
-namespace Akonadi
-{
-class EntityTreeModel;
-}
-
 namespace EventViews
 {
 class AgendaView;
