@@ -24,11 +24,11 @@ public:
         virtual bool operator==(const Node &) const;
 
     protected:
-        Node(ReparentingModel &personModel);
+        explicit Node(ReparentingModel &personModel);
 
     private:
         friend class ReparentingModel;
-        Node(ReparentingModel &personModel, Node *parent, const QModelIndex &sourceIndex);
+        Node(ReparentingModel &model, Node *parent, const QModelIndex &sourceIndex);
         virtual QVariant data(int role) const;
         virtual bool setData(const QVariant &variant, int role);
         virtual bool adopts(const QModelIndex &sourceIndex);
@@ -37,7 +37,6 @@ public:
 
         bool isSourceNode() const;
         Node::Ptr searchNode(Node *node);
-        void reparent(Node *node);
         void addChild(const Node::Ptr &node);
         int row() const;
         void clearHierarchy();
@@ -46,13 +45,13 @@ public:
         QList<Ptr> children;
         Node *parent = nullptr;
         ReparentingModel &personModel;
-        const bool mIsSourceNode = false;
+        const bool mIsSourceNode; // init in the ctors
     };
 
     struct NodeManager {
         using Ptr = QSharedPointer<NodeManager>;
 
-        NodeManager(ReparentingModel &m)
+        explicit NodeManager(ReparentingModel &m)
             : model(m)
         {
         }
@@ -88,7 +87,6 @@ public:
     void addNode(const Node::Ptr &node);
     void updateNode(const Node::Ptr &node);
     void removeNode(const Node &node);
-    void setNodes(const QList<Node::Ptr> &nodes);
     void clear();
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
@@ -117,10 +115,10 @@ private Q_SLOTS:
     void onSourceLayoutChanged();
     void onSourceModelAboutToBeReset();
     void onSourceModelReset();
-    void doAddNode(const Node::Ptr &node);
+    void doAddNode(const ReparentingModel::Node::Ptr &node);
 
 private:
-    void rebuildFromSource(Node *parentNode, const QModelIndex &idx, const QModelIndexList &skip = QModelIndexList());
+    void rebuildFromSource(Node *parentNode, const QModelIndex &sourceParent, const QModelIndexList &skip = QModelIndexList());
     bool isDuplicate(const Node::Ptr &proxyNode) const;
     void insertProxyNode(const Node::Ptr &proxyNode);
     void reparentSourceNodes(const Node::Ptr &proxyNode);
@@ -131,7 +129,7 @@ private:
     Node *getParentNode(const QModelIndex &sourceIndex);
     bool validateNode(const Node *node) const;
     Node *extractNode(const QModelIndex &index) const;
-    void appendSourceNode(Node *parentNode, const QModelIndex &sourceIndex, const QModelIndexList &skip = QModelIndexList());
+    void appendSourceNode(Node *parentNode, const QModelIndex &sourceParent, const QModelIndexList &skip = QModelIndexList());
     QModelIndexList descendants(const QModelIndex &sourceIndex);
     void removeDuplicates(const QModelIndex &sourceIndex);
     Node *getSourceNode(const QModelIndex &sourceIndex) const;
