@@ -34,7 +34,7 @@ using namespace KOrg;
 
 static QString generateColumnLabel(int c)
 {
-    return i18n("Agenda %1", c + 1);
+    return i18nc("@title:column", "Agenda %1", c + 1);
 }
 
 class CalendarViewCalendarFactory : public EventViews::MultiAgendaView::CalendarFactory
@@ -42,7 +42,7 @@ class CalendarViewCalendarFactory : public EventViews::MultiAgendaView::Calendar
 public:
     using Ptr = QSharedPointer<CalendarViewCalendarFactory>;
 
-    CalendarViewCalendarFactory(CalendarViewBase *calendarView)
+    explicit CalendarViewCalendarFactory(CalendarViewBase *calendarView)
         : mView(calendarView)
     {
     }
@@ -76,6 +76,9 @@ public:
     Akonadi::Collection::Id mCollectionId = -1;
 
 private:
+    // disable copy ctor
+    MultiAgendaViewPrivate(const MultiAgendaViewPrivate &) = delete;
+    MultiAgendaViewPrivate &operator=(const MultiAgendaViewPrivate &) = delete;
     MultiAgendaView *const q;
 };
 
@@ -247,7 +250,7 @@ bool MultiAgendaView::hasConfigurationDialog() const
 
 void MultiAgendaView::showConfigurationDialog(QWidget *parent)
 {
-    QPointer<MultiAgendaViewConfigDialog> dlg(new MultiAgendaViewConfigDialog(d->mCollectionSelectionModel, parent));
+    const QPointer<MultiAgendaViewConfigDialog> dlg(new MultiAgendaViewConfigDialog(d->mCollectionSelectionModel, parent));
 
     dlg->setUseCustomColumns(d->mMultiAgendaView->customColumnSetupUsed());
     dlg->setNumberOfColumns(d->mMultiAgendaView->customNumberOfColumns());
@@ -288,11 +291,9 @@ void MultiAgendaView::setCollectionSelectionProxyModel(KCheckableProxyModel *mod
 class KOrg::MultiAgendaViewConfigDialogPrivate
 {
 public:
-    MultiAgendaViewConfigDialog *const q;
     explicit MultiAgendaViewConfigDialogPrivate(QAbstractItemModel *base, MultiAgendaViewConfigDialog *qq)
         : q(qq)
         , baseModel(base)
-        , currentColumn(0)
     {
     }
 
@@ -302,15 +303,16 @@ public:
     }
 
     void setUpColumns(int n);
-    AkonadiCollectionView *createView(KCheckableProxyModel *model);
     [[nodiscard]] AkonadiCollectionView *view(int index) const;
+    AkonadiCollectionView *createView(KCheckableProxyModel *model);
+    MultiAgendaViewConfigDialog *const q;
     QList<KCheckableProxyModel *> newlyCreated;
     QList<KCheckableProxyModel *> selections;
     QList<QString> titles;
     Ui::MultiAgendaViewConfigWidget ui;
     QStandardItemModel listModel;
     QAbstractItemModel *baseModel = nullptr;
-    int currentColumn;
+    int currentColumn = 0;
 };
 
 void MultiAgendaView::restoreConfig(const KConfigGroup &configGroup)
@@ -355,7 +357,7 @@ MultiAgendaViewConfigDialog::MultiAgendaViewConfigDialog(QAbstractItemModel *bas
     connect(d->ui.useCustomRB, &QAbstractButton::toggled, this, &MultiAgendaViewConfigDialog::useCustomToggled);
     connect(d->ui.columnNumberSB, &QSpinBox::valueChanged, this, &MultiAgendaViewConfigDialog::numberOfColumnsChanged);
     connect(d->ui.titleLE, &QLineEdit::textEdited, this, &MultiAgendaViewConfigDialog::titleEdited);
-    d->setUpColumns(numberOfColumns());
+    d->setUpColumns(d->ui.columnNumberSB->value());
     useCustomToggled(false);
 }
 
